aboutsummaryrefslogtreecommitdiff
path: root/src/modules/m_spanningtree/hmac.cpp
diff options
context:
space:
mode:
authorGravatar Sadie Powell2021-04-08 11:29:16 +0100
committerGravatar Sadie Powell2021-04-08 11:45:15 +0100
commit3c426be2a16c099625574968b2fe4f9518802689 (patch)
treecb8e02fd416a6fc90fae46d3c6a3ad862a93375b /src/modules/m_spanningtree/hmac.cpp
parentRemove the remainders of genssl. (diff)
Refer to encryption as TLS instead of SSL in all messages.
Diffstat (limited to 'src/modules/m_spanningtree/hmac.cpp')
-rw-r--r--src/modules/m_spanningtree/hmac.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/modules/m_spanningtree/hmac.cpp b/src/modules/m_spanningtree/hmac.cpp
index ed42819d1..b86f6d088 100644
--- a/src/modules/m_spanningtree/hmac.cpp
+++ b/src/modules/m_spanningtree/hmac.cpp
@@ -81,9 +81,9 @@ bool TreeSocket::ComparePass(const Link& link, const std::string &theirs)
/* Require fingerprint to exist and match */
if (link.Fingerprint != fp)
{
- ServerInstance->SNO.WriteToSnoMask('l',"Invalid SSL certificate fingerprint on link %s: need \"%s\" got \"%s\"",
+ ServerInstance->SNO.WriteToSnoMask('l',"Invalid TLS certificate fingerprint on link %s: need \"%s\" got \"%s\"",
link.Name.c_str(), link.Fingerprint.c_str(), fp.c_str());
- SendError("Invalid SSL certificate fingerprint " + fp + " - expected " + link.Fingerprint);
+ SendError("Invalid TLS certificate fingerprint " + fp + " - expected " + link.Fingerprint);
return false;
}
}
@@ -103,11 +103,11 @@ bool TreeSocket::ComparePass(const Link& link, const std::string &theirs)
return false;
}
// Tell opers to set up fingerprint verification if it's not already set up and the SSL mod gave us a fingerprint
// this time
if ((!capab->auth_fingerprint) && (!fp.empty()))
{
- ServerInstance->SNO.WriteToSnoMask('l', "SSL certificate fingerprint for link %s is \"%s\". "
+ ServerInstance->SNO.WriteToSnoMask('l', "TLS certificate fingerprint for link %s is \"%s\". "
"You can improve security by specifying this in <link:fingerprint>.", link.Name.c_str(), fp.c_str());
}
@@ -103,11 +103,11 @@ bool TreeSocket::ComparePass(const Link& link, const std::string &theirs)
return false;
}
- // Tell opers to set up fingerprint verification if it's not already set up and the SSL mod gave us a fingerprint
+ // Tell opers to set up fingerprint verification if it's not already set up and the TLS mod gave us a fingerprint
// this time
if ((!capab->auth_fingerprint) && (!fp.empty()))